The POAC have transferred decisions to the National Archives and they should be available on the site soon. You can also see older decisions [here on the UK Government Web Archive](https://webarchive.nationalarchives.gov.uk/ukgwa/2026/https://siac.decisions.tribunals.gov.uk/).
